#
# spec file for package fluxbox
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fluxbox
Version:        1.3.7
Release:        2.3
Summary:        A window manager for X based on Blackbox 0.61.1
License:        MIT
Group:          System/GUI/Other
URL:            http://www.fluxbox.org/
Source0:        https://downloads.sourceforge.net/project/fluxbox/%{name}/%{version}/%{name}-%{version}.tar.xz
Source1:        fluxboxmenu
Source2:        SUSE.tar.bz2
Source3:        fluxbox.desktop
# PATCH-FIX-OPENSUSE fluxbox-remove_build_timestamp.patch -- removes __DATE and __TIME from the resulting binary
Patch1:         fluxbox-remove_build_timestamp.patch
Patch2:         gcc11.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Recommends:     %{name}-styles-upstream
Provides:       windowmanager

BuildRequires:  fribidi-devel
BuildRequires:  gcc-c++
BuildRequires:  imlib2-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
# fdupes not available on SLE10
%if 0%{?suse_version} >= 1100
BuildRequires:  fdupes
%endif

%description
Fluxbox is a stacking windowmanager for the X Window System which
started as a fork of Blackbox 0.61.1 in 2001. Its user interface has
only a taskbar, a pop-up menu accessible by right-clicking on the
desktop, and minimal support for graphical icons. All basic
configurations are controlled by text files, including the
construction of menus and the mapping of key-bindings. Fluxbox
supports the Extended Window Manager Hints specification.

%package styles-upstream
Summary:        Upstream bundle of styles for fluxbox
Group:          System/GUI/Other
BuildArch:      noarch
Requires:       %{name}

%description styles-upstream
Fluxbox is a stacking windowmanager for the X Window System which
started as a fork of Blackbox 0.61.1 in 2001. Its user interface has
only a taskbar, a pop-up menu accessible by right-clicking on the
desktop, and minimal support for graphical icons.

This package provides the upstream bundle of styles.

%prep
%setup -q -a 2
%patch -P 1
%patch -P 2 -p1

%build
export RPM_OPT_FLAGS="%{optflags} -fno-strict-aliasing -Wno-unused"
export CFLAGS="$RPM_OPT_FLAGS -fvisibility=hidden"
export CXXFLAGS="$RPM_OPT_FLAGS -fvisibility=hidden -fvisibility-inlines-hidden"

%configure \
   --enable-remember \
   --enable-regexp \
   --enable-slit \
   --enable-toolbar \
   --enable-ewnh \
   --enable-nls \
   --enable-timedcache \
   --enable-xft \
   --enable-xrender \
   --enable-xpm \
   --enable-imlib2 \
   --enable-xmb \
   --enable-xinerama \
   --enable-shape \
   --enable-randr \
   --enable-fribidi \
   --with-style=%{_datadir}/fluxbox/styles/SUSE
make %{?_smp_mflags} V=1

%install
%make_install
# Install desktop file for xdm/gdm
install -D -m 0644 %{SOURCE3} %{buildroot}%{_datadir}/xsessions/fluxbox.desktop
# menu
install -m 644 %{SOURCE1} %{buildroot}%{_datadir}/fluxbox/menu
# theme
mv SUSE %{buildroot}%{_datadir}/fluxbox/styles/
# fdupes not available on SLE10
%if 0%{?suse_version} >= 1100
%fdupes %{buildroot}%{_datadir}/%{name}
%endif

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog NEWS README
%dir %{_datadir}/fluxbox/
%dir %{_datadir}/fluxbox/styles
%{_bindir}/fluxbox*
%{_bindir}/startfluxbox
%{_bindir}/fbrun
%{_bindir}/fbsetbg
%{_bindir}/fbsetroot
%{_datadir}/fluxbox/apps
%{_datadir}/fluxbox/init
%{_datadir}/fluxbox/keys
%{_datadir}/fluxbox/menu
%{_datadir}/fluxbox/overlay
%{_datadir}/fluxbox/windowmenu
%{_datadir}/fluxbox/nls/
%{_datadir}/fluxbox/styles/SUSE/
%{_datadir}/xsessions/fluxbox.desktop
%{_mandir}/man1/fluxbox.1*
%{_mandir}/man1/startfluxbox.1*
%{_mandir}/man1/fbsetroot.1*
%{_mandir}/man1/fbsetbg.1*
%{_mandir}/man1/fbrun.1*
%{_mandir}/man1/fluxbox-remote.1*
%{_mandir}/man5/fluxbox-keys.5*
%{_mandir}/man5/fluxbox-apps.5*
%{_mandir}/man5/fluxbox-menu.5*
%{_mandir}/man5/fluxbox-style.5*

%files styles-upstream
%defattr(-,root,root,-)
%{_datadir}/fluxbox/styles/Artwiz
%{_datadir}/fluxbox/styles/BlueFlux/
%{_datadir}/fluxbox/styles/BlueNight
%{_datadir}/fluxbox/styles/Emerge/
%{_datadir}/fluxbox/styles/Flux
%{_datadir}/fluxbox/styles/LemonSpace
%{_datadir}/fluxbox/styles/Makro
%{_datadir}/fluxbox/styles/MerleyKay
%{_datadir}/fluxbox/styles/Nyz
%{_datadir}/fluxbox/styles/Operation
%{_datadir}/fluxbox/styles/Outcomes
%{_datadir}/fluxbox/styles/Results
%{_datadir}/fluxbox/styles/Shade
%{_datadir}/fluxbox/styles/Twice
%{_datadir}/fluxbox/styles/arch/
%{_datadir}/fluxbox/styles/bloe/
%{_datadir}/fluxbox/styles/bora_black/
%{_datadir}/fluxbox/styles/bora_blue/
%{_datadir}/fluxbox/styles/bora_green/
%{_datadir}/fluxbox/styles/carp/
%{_datadir}/fluxbox/styles/green_tea/
%{_datadir}/fluxbox/styles/ostrich/
%{_datadir}/fluxbox/styles/qnx-photon
%{_datadir}/fluxbox/styles/zimek_bisque/
%{_datadir}/fluxbox/styles/zimek_darkblue/
%{_datadir}/fluxbox/styles/zimek_green/
%{_datadir}/fluxbox/styles/Meta

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Jul  3 2021 Fernando Mattioli <mattioli.fernando@gmail.com>
- Add gcc11.patch: replaces ordered pointer comparison with equality comparison.
* Wed Jun  7 2017 jengelh@inai.de
- Replace filler wording by some factual description.
* Sun Sep 20 2015 sbahling@suse.com
- update to 1.3.7:
  Critical Bugfixes:
  * Segfault on startup (mostly *BSD)
  * Segfault on shutdown
  * Segfault on clicking the Remember menu
  * Menu crops on TypeAhead
  Minor Bugfixes:
  * _NET_REQUEST_FRAME_EXTENTS
  * Working autorepeat keys
  * Working vertical rotated Tabs and Toolbar
  * Proper size of titlebar buttons on restart / detaching tabs
  * Missing windowmenu works again
  * Several glitches in the menu
  * Correct handling of 'maximized' statement in the apps file
  Features:
  * The improved TypeAhead sytem is not limited to matches on beginning
    of menu items anymore, the behavior is configurable:
  - Nowhere - disables TypeAhead support
  - ItemStart - matches typed text only at the start of a menu item
  - Somewhere - matches typed text somewhere in a menu item
    (Currently this is a configfile-only option)
  * Minor tweaks to the i18n system
  * Updated turkish translations
  End User unrelated:
  * Code refactoring and cleanup, assisted by Coverity and
    clang static code analysis
- changes from 1.3.6:
  Critical Bugfixes:
  * Clocktool problems
  * Rendering long text
  * Race condition on shutdown
  * Lost keypresses after workspace switch
  * Corruption of fbrun-history
  Minor Bugfixes:
  * Resize and Move problems
  Features:
  * 'ArrangeWindowsStack' action
  * Treat Windows with WM_CLASS == "DockApp" as DockApps
  Minor:
  * Updated translations (Bulgarian, Hebrew, Japanese)
  * Updated build system
- Update Source0 URL in specfile
- Use xz compressed source tarball
- Rebase fluxbox-remove_build_timestamp.patch
* Tue Sep 30 2014 crrodriguez@opensuse.org
- Do not use xorg-x11-devel but only the needed packages.
- Build with -fvisibility-hidden there is no shared library
  exporting an API or loadable plugins so we do not have
  to pay for that at runtime.
* Fri Feb 14 2014 stephan.barth@suse.com
- fixed file list for fluxbox-styles-upstream, which sometimes had trailing
  slashes for regular files
* Tue Feb 19 2013 nmo.marques@gmail.com
- update to 1.3.5:
  * Bugfix: reenable 'If', 'Or', 'And' actions.
- fixes from 1.3.4:
  * More subtle brightening of colors
  * FbTk::FbTime::mono() yields microseconds since fluxbox started
  * Feature: Added 'LHalf' / 'RHalf' buttons for titlebar
  * Bugfix: Elliptic gradients are rendered correctly now
  * Bugfix: Avoid integer overflow for some gradients
  * Code optimization in texture rendering code (RAM, reduced branches)
  * Feature: Added 'ClientPatternTest' command to help debugging
    client patterns via 'fluxbox-remote'
  * Bugfix: Handle FbTk::Timers with equal end time correctly
  * Bugfix: Align ClockTool timers with system clock to trigger clock
    switches when the users expects them
  * Improved calculation of brighter colors
  * Added 'he_IL' translations (Thanks Genghis Khan)
  * Bugfix: Invert a texture correctly
  * Cleanup of build-system and .gitignore
  * Simplification of FbTK::Timer code
  * Simplification of FbTK::TextureRender code
  * Use the same lookup-tables for solid colors and gradient textures
  * Bugfix: Do not handle list of timers in place
  * Improved documentation of code
  * Including the code of the SystemTray into the binary is optional now
  * Reduce window-movement lagging on slower systems (Thanks Aymeric Vincent)
  * Build-system improvements (Thanks Sami Kerola)
  * Removed bashisms from fluxbox-generate_menu (Thanks Sami Kerola)
  * Build-system improvements (Thanks Sami Kerola)
  * Combile fix: forgotten parentheses in code for MacOS
* Wed Jan 23 2013 nmo.marques@gmail.com
- update license field to match http://spdx.org/licenses/ (MIT)
- split upstream styles into sub-package; keep SUSE style in the
  main package to comply with %%configure macro
- update summary for review (clears through rpmlint 'warning')
- fix typos and update syntax in configure: --enable-newspec,
  - -enable-timedcache, --enable-randr.
- spec cleanups
* Wed Jan 16 2013 nmo.marques@gmail.com
- update to 1.3.3
  * Added 'NearestCorner', 'NearestEdge' and 'NearestCornerOrEdge' resize
    methods
  * Added percentage values for commands such as ResizeWindow
  * Added style ressources 'menu.hilite.font', 'menu.hilite.justify'
  * Added 'OnTab' modifier for keys file
  * Added _MOTIF_WM_INFO atom to advertise motif capabilities
  * Added 'fullscreen', 'maximizedhorizontal', 'maximizedvertical' tests to
    client patterns
  * Added option to revert focus to previous window only on current head in
    a multi-monitor setup
  * Rewrite of FbTk::TextureRenderer (simpler code)
  * Improved building on Microsoft Windows
  * Use of monotonic increasing clock for timer, not affected by leap seconds etc.
  * Fixed placement off transient windows in a multi-monitor setup with 'holes'
  * Fixed usage of '~' as part of style filenames
  * Replaced (deprecated) XKeycodeToKeysym() with XkbKeycodeToKeysym()
  * Improved vertical alignment of text in decorations
  * Fixed compiler and code style issues
  * Updated italian translations
- update license to match spdx.org
- update summary to match review (requested for update, silly one)
* Wed Nov  2 2011 pascal.bleser@opensuse.org
- update to 1.3.2:
  * support for ARG32 visuals (cairo-dock etc)
  * updated translations
  * removed Gnome window manager hints
  * relicense 'ostrich' theme
  * support CARDINAL for client pattern
  * fix crash at SIGINT / exit
  * fix signal/Slot related crashes on exit
  * sync bootstraped config files to disk before launching
  * don't warp workspaces on single workspaces
  * fix crash when using ClientMenu after changing the client, sf#3210493
  * remap keysyms to keycodes after 'MappingNotify' (setxkbmap, xmodmap),
    sf#3386257
  * use _NET_WM_ICON correctly, sf#1852693
  * updated 'bloe' and 'arch' styles to work without XPM support
- dropped the following patches, merged upstream in 1.3.2:
  * fluxbox-ftbfs-gcc-4.6.patch
  * fluxbox-upstream-3a3df518.patch
- added patch to remove __DATE and __TIME (build timestamps)
* Mon Oct 24 2011 nmarques@opensuse.org
- Remove fluxbox-1.1.0-missing_includes.patch
- Remove fluxbox-1.3.1-no-return.patch
- Add fluxbox-ftbfs-gcc-4.6.patch: fix FTBFS, taken from upstream
- Add fluxbox-upstream-3a3df518.patch: cosmetic solution taken
  from upstream. Replace fluxbox-1.3.1-no-return.patch
- Install .desktop file for GDM/XDM
- Add fribidi-devel to BuildRequires
- Add fdupes to BuildRequires if suse_version >= 1100
* Tue Mar 22 2011 highwaystar.ru@gmail.com
- updated to 1.3.1
  * Fix for not hiding submenus if menuDelay is set.
  * Fix crash when moving transient windows (Dialogs) between Workspaces, #3088856.
  * Fix crash when SystemTray was rotated 90/270 degree, #3188223.
  * Fix potential crash when gettting an UnmapEvent before a FocusEvent.
  * Fix potential crash on accessing NULL-pointer.
  * Fix wrong width calculation of Systemtray, #3150939.
  * Fix initial placement of WindowMenu, #2731524.
  * Fix incorrectly shown alpha values in Menus, #3187373.
  * Fix render 'sunken' Textures correctly.
- package changelog moved to .changes
* Mon Feb 21 2011 posix.ru@gmail.com
- update to 1.3.0
* Thu Jan  8 2009 mmj@mmj.dk
- Remove checks for version before 9.2 and 10.2, they are both
  discontinued
- Update to version 1.1.1, with the following changes since 1.1.0:
  * Fixed a minor pixmap resource leak
  * Fixed unshading crash
  * Be aware of badly specified _NET_WM_ICONS
  * Added windowmenu to distpackage
* Thu Oct 25 2007 henne@links2linux.de
- update to 1.0.0 final
* Fri Jun 29 2007 henne@links2linux.de
- update to rc3
* Thu Nov 30 2006 henne@links2linux.de
- update to rc2
- move to %%_bindir for 10.2
* Thu Jun 22 2006 henne@links2linux.de
- Shot myself in the foot with replacing the Meta directory with a file
* Wed Jun 21 2006 henne@links2linux.de
- Update to 1.0rc release
- make use of with-style instead of replacing the Meta style
- Update included theme to match new background handling
* Tue Mar 21 2006 henne@links2linux.de
- update to version 0.9.15
- drop namespace patch. its included
* Tue Feb 28 2006 henne@links2linux.de
- fix suse version macro usage
* Thu Feb  2 2006 henne@links2linux.de
- gcc 4.1 patch for SUSE Linux 10.1
- %%if the Buildrequires a bit.
* Mon Sep 19 2005 henne@links2linux.de
- update to version 0.9.14
* Fri Jun 17 2005 henne@links2linux.de
- update to version 0.9.13
* Wed Jan 19 2005 henne@links2linux.de
- update to version 0.9.12
* Tue Dec  7 2004 henne@links2linux.de
- update to version 0.9.11
* Tue Nov  2 2004 henne@links2linux.de
- fix x86_64 build
* Sun Aug 29 2004 henne@links2linux.de
- Initial Packman Package, Version 0.9.10
